## Copyright (C) 2012 pdiribarne
## 
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn  {Function File} {@var{hnew} =} copyobj (@var{horig})
## Constructs a copy of the object associated whith handle @var{horig}
## and returns a handle, @var{hnew}, to the new object.
## @seealso{findobj, get, set, struct2hdl, hdl2struct}
## @end deftypefn

## Author: pdiribarne <pdiribarne@new-host.home>
## Created: 2012-04-01

function hout = copyobj (hin)

  if !ishandle (hin)
    print_usage ();
  elseif (strcmpi (get (hin).tag, "legend"))
    error ("copyobj: legends must be copied with their correponding objects")
  elseif (strcmpi (get (hin).tag, "colorbar"))
    error ("copyobj: colorbars must be copied with their sister axis object")
  endif

  str = hdl2struct (hin);
  hout = struct2hdl (str);
  
endfunction

%!demo
%! hdl = figure (1234);
%! clf ()
%! hold on
%! x = 1:10;
%! y = x.^2;
%! dy = 2 * (.2 * x);
%! y2 = (x - 3).^2;
%! hg = errorbar (x, y, dy,'#~');
%! set (hg, 'marker', '^', 'markerfacecolor', rand(1,3))
%! plot (x, y2, 'ok-')
%! legend ('errorbar', 'line')
%! hout = copyobj (1234);

%!demo
%! hdl = figure (1234);
%! clf ()
%! subplot (2, 2, 1);
%! hold on
%! [C, H] = contourf (rand(10, 10));
%! colorbar
%! subplot (2, 2, 2);
%! hold on
%! quiver (rand(10, 10), rand(10, 10))
%! subplot (2, 2, 3);
%! colormap (jet (64))
%! sombrero;
%! colorbar('peer', gca, 'NorthOutside')
%! subplot (2, 2, 4);
%! imagesc (rand (30, 30));
%! text (15, 15, 'Rotated text', ...
%!      'HorizontAlalignment', 'Center', 'Rotation', 30);
%! hout = copyobj (1234);

